Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2)

Unified Diff: include/core/SkImageFilter.h

Issue 134163010: Refactor read and write buffers. (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: whoops, read buffers have .size() Created 6 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « include/core/SkFlattenableBuffers.h ('k') | include/core/SkImageInfo.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/core/SkImageFilter.h
diff --git a/include/core/SkImageFilter.h b/include/core/SkImageFilter.h
index 25d3bac8020b5b3a82224c5ee9424fe6c01201d8..37993c0ea3e2a527eafb2709061341c3e8fe86f3 100644
--- a/include/core/SkImageFilter.h
+++ b/include/core/SkImageFilter.h
@@ -160,15 +160,15 @@ protected:
virtual ~SkImageFilter();
/**
* Constructs a new SkImageFilter read from an SkFlattenableReadBuffer object.
*
* @param inputCount The exact number of inputs expected for this SkImageFilter object.
* -1 can be used if the filter accepts any number of inputs.
* @param rb SkFlattenableReadBuffer object from which the SkImageFilter is read.
*/
- explicit SkImageFilter(int inputCount, SkFlattenableReadBuffer& rb);
+ explicit SkImageFilter(int inputCount, SkReadBuffer& rb);
- virtual void flatten(SkFlattenableWriteBuffer& wb) const SK_OVERRIDE;
+ virtual void flatten(SkWriteBuffer& wb) const SK_OVERRIDE;
/**
* This is the virtual which should be overridden by the derived class
« no previous file with comments | « include/core/SkFlattenableBuffers.h ('k') | include/core/SkImageInfo.h » ('j') | no next file with comments »
@@ -160,15 +160,15 @@ protected:
virtual ~SkImageFilter();
/**
- * Constructs a new SkImageFilter read from an SkFlattenableReadBuffer object.
+ * Constructs a new SkImageFilter read from an SkReadBuffer object.
*
* @param inputCount The exact number of inputs expected for this SkImageFilter object.
@@ -160,15 +160,15 @@ protected:
* @param inputCount The exact number of inputs expected for this SkImageFilter object.
* -1 can be used if the filter accepts any number of inputs.
- * @param rb SkFlattenableReadBuffer object from which the SkImageFilter is read.
+ * @param rb SkReadBuffer object from which the SkImageFilter is read.
*/

Powered by Google App Engine
This is Rietveld 408576698